@@ -3,10 +3,10 @@ import Catalog from './catalog/catalog';
 import ToolbarButton from './components/toolbar/toolbar-button';
 import Ruler from './components/viewer2d/ruler';
 import * as Models from './models'
+import PluginBrowserAutosave from './plugins/browser-autosave/browser-autosave';
 
 console.info(`react-planner started`); //MIT LICENSE COMPLIANT
 
-
 export {
-  Planner, Catalog, ToolbarButton, Ruler, Models
+  Planner, Catalog, ToolbarButton, Ruler, Models, PluginBrowserAutosave
 };
